# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/planning/proto/planning_internal.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import geometry_pb2 as modules_dot_common_dot_proto_dot_geometry__pb2
from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2
from modules.canbus.proto import chassis_pb2 as modules_dot_canbus_dot_proto_dot_chassis__pb2
from modules.common.proto import pnc_point_pb2 as modules_dot_common_dot_proto_dot_pnc__point__pb2
from modules.localization.proto import localization_pb2 as modules_dot_localization_dot_proto_dot_localization__pb2
from modules.dreamview.proto import chart_pb2 as modules_dot_dreamview_dot_proto_dot_chart__pb2
from modules.map.relative_map.proto import navigation_pb2 as modules_dot_map_dot_relative__map_dot_proto_dot_navigation__pb2
from modules.routing.proto import routing_pb2 as modules_dot_routing_dot_proto_dot_routing__pb2
from modules.perception.proto import traffic_light_detection_pb2 as modules_dot_perception_dot_proto_dot_traffic__light__detection__pb2
from modules.planning.proto import sl_boundary_pb2 as modules_dot_planning_dot_proto_dot_sl__boundary__pb2
from modules.planning.proto import decision_pb2 as modules_dot_planning_dot_proto_dot_decision__pb2
from modules.planning.proto import planning_config_pb2 as modules_dot_planning_dot_proto_dot_planning__config__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/planning/proto/planning_internal.proto',
  package='apollo.planning_internal',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.modules/planning/proto/planning_internal.proto\x12\x18\x61pollo.planning_internal\x1a#modules/common/proto/geometry.proto\x1a!modules/common/proto/header.proto\x1a\"modules/canbus/proto/chassis.proto\x1a$modules/common/proto/pnc_point.proto\x1a-modules/localization/proto/localization.proto\x1a#modules/dreamview/proto/chart.proto\x1a/modules/map/relative_map/proto/navigation.proto\x1a#modules/routing/proto/routing.proto\x1a\x36modules/perception/proto/traffic_light_detection.proto\x1a(modules/planning/proto/sl_boundary.proto\x1a%modules/planning/proto/decision.proto\x1a,modules/planning/proto/planning_config.proto\"F\n\x05\x44\x65\x62ug\x12=\n\rplanning_data\x18\x02 \x01(\x0b\x32&.apollo.planning_internal.PlanningData\"I\n\tSpeedPlan\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\x0bspeed_point\x18\x02 \x03(\x0b\x32\x19.apollo.common.SpeedPoint\"\x86\x03\n\x14StGraphBoundaryDebug\x12\x0c\n\x04name\x18\x01 \x01(\t\x12(\n\x05point\x18\x02 \x03(\x0b\x32\x19.apollo.common.SpeedPoint\x12K\n\x04type\x18\x03 \x01(\x0e\x32=.apollo.planning_internal.StGraphBoundaryDebug.StBoundaryType\"\xe8\x01\n\x0eStBoundaryType\x12\x1c\n\x18ST_BOUNDARY_TYPE_UNKNOWN\x10\x01\x12\x19\n\x15ST_BOUNDARY_TYPE_STOP\x10\x02\x12\x1b\n\x17ST_BOUNDARY_TYPE_FOLLOW\x10\x03\x12\x1a\n\x16ST_BOUNDARY_TYPE_YIELD\x10\x04\x12\x1d\n\x19ST_BOUNDARY_TYPE_OVERTAKE\x10\x05\x12\x1f\n\x1bST_BOUNDARY_TYPE_KEEP_CLEAR\x10\x06\x12$\n ST_BOUNDARY_TYPE_DRIVABLE_REGION\x10\x07\"\x82\x03\n\x0cSLFrameDebug\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tsampled_s\x18\x02 \x03(\x01\x12#\n\x1bstatic_obstacle_lower_bound\x18\x03 \x03(\x01\x12$\n\x1c\x64ynamic_obstacle_lower_bound\x18\x04 \x03(\x01\x12#\n\x1bstatic_obstacle_upper_bound\x18\x05 \x03(\x01\x12$\n\x1c\x64ynamic_obstacle_upper_bound\x18\x06 \x03(\x01\x12\x17\n\x0fmap_lower_bound\x18\x07 \x03(\x01\x12\x17\n\x0fmap_upper_bound\x18\x08 \x03(\x01\x12\'\n\x07sl_path\x18\t \x03(\x0b\x32\x16.apollo.common.SLPoint\x12\x1d\n\x15\x61ggregated_boundary_s\x18\n \x03(\x01\x12\x1f\n\x17\x61ggregated_boundary_low\x18\x0b \x03(\x01\x12 \n\x18\x61ggregated_boundary_high\x18\x0c \x03(\x01\"\x92\x05\n\x0cSTGraphDebug\x12\x0c\n\x04name\x18\x01 \x01(\t\x12@\n\x08\x62oundary\x18\x02 \x03(\x0b\x32..apollo.planning_internal.StGraphBoundaryDebug\x12.\n\x0bspeed_limit\x18\x03 \x03(\x0b\x32\x19.apollo.common.SpeedPoint\x12\x30\n\rspeed_profile\x18\x04 \x03(\x0b\x32\x19.apollo.common.SpeedPoint\x12W\n\x10speed_constraint\x18\x05 \x01(\x0b\x32=.apollo.planning_internal.STGraphDebug.STGraphSpeedConstraint\x12W\n\x11kernel_cruise_ref\x18\x06 \x01(\x0b\x32<.apollo.planning_internal.STGraphDebug.STGraphKernelCuiseRef\x12X\n\x11kernel_follow_ref\x18\x07 \x01(\x0b\x32=.apollo.planning_internal.STGraphDebug.STGraphKernelFollowRef\x1aM\n\x16STGraphSpeedConstraint\x12\t\n\x01t\x18\x01 \x03(\x01\x12\x13\n\x0blower_bound\x18\x02 \x03(\x01\x12\x13\n\x0bupper_bound\x18\x03 \x03(\x01\x1a\x39\n\x15STGraphKernelCuiseRef\x12\t\n\x01t\x18\x01 \x03(\x01\x12\x15\n\rcruise_line_s\x18\x02 \x03(\x01\x1a:\n\x16STGraphKernelFollowRef\x12\t\n\x01t\x18\x01 \x03(\x01\x12\x15\n\rfollow_line_s\x18\x02 \x03(\x01\"\xad\x02\n\x10SignalLightDebug\x12\x11\n\tadc_speed\x18\x01 \x01(\x01\x12\x13\n\x0b\x61\x64\x63_front_s\x18\x02 \x01(\x01\x12\x46\n\x06signal\x18\x03 \x03(\x0b\x32\x36.apollo.planning_internal.SignalLightDebug.SignalDebug\x1a\xa8\x01\n\x0bSignalDebug\x12\x10\n\x08light_id\x18\x01 \x01(\t\x12\x34\n\x05\x63olor\x18\x02 \x01(\x0e\x32%.apollo.perception.TrafficLight.Color\x12\x14\n\x0clight_stop_s\x18\x03 \x01(\x01\x12\x1d\n\x15\x61\x64\x63_stop_deceleration\x18\x04 \x01(\x01\x12\x1c\n\x14is_stop_wall_created\x18\x05 \x01(\x08\"Y\n\x0b\x44\x65\x63isionTag\x12\x13\n\x0b\x64\x65\x63ider_tag\x18\x01 \x01(\t\x12\x35\n\x08\x64\x65\x63ision\x18\x02 \x01(\x0b\x32#.apollo.planning.ObjectDecisionType\"\xc0\x01\n\rObstacleDebug\x12\n\n\x02id\x18\x01 \x01(\t\x12\x30\n\x0bsl_boundary\x18\x02 \x01(\x0b\x32\x1b.apollo.planning.SLBoundary\x12;\n\x0c\x64\x65\x63ision_tag\x18\x03 \x03(\x0b\x32%.apollo.planning_internal.DecisionTag\x12\x19\n\x11vertices_x_coords\x18\x04 \x03(\x01\x12\x19\n\x11vertices_y_coords\x18\x05 \x03(\x01\"\xd9\x02\n\x12ReferenceLineDebug\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06length\x18\x02 \x01(\x01\x12\x0c\n\x04\x63ost\x18\x03 \x01(\x01\x12\x1b\n\x13is_change_lane_path\x18\x04 \x01(\x08\x12\x13\n\x0bis_drivable\x18\x05 \x01(\x08\x12\x14\n\x0cis_protected\x18\x06 \x01(\x08\x12\x12\n\nis_offroad\x18\x07 \x01(\x08\x12\x18\n\x10minimum_boundary\x18\x08 \x01(\x01\x12\x19\n\raverage_kappa\x18\t \x01(\x01\x42\x02\x18\x01\x12\x1a\n\x0e\x61verage_dkappa\x18\n \x01(\x01\x42\x02\x18\x01\x12\x11\n\tkappa_rms\x18\x0b \x01(\x01\x12\x12\n\ndkappa_rms\x18\x0c \x01(\x01\x12\x15\n\rkappa_max_abs\x18\r \x01(\x01\x12\x16\n\x0e\x64kappa_max_abs\x18\x0e \x01(\x01\x12\x16\n\x0e\x61verage_offset\x18\x0f \x01(\x01\"<\n\x10SampleLayerDebug\x12(\n\x08sl_point\x18\x01 \x03(\x0b\x32\x16.apollo.common.SLPoint\"\x84\x01\n\x10\x44pPolyGraphDebug\x12@\n\x0csample_layer\x18\x01 \x03(\x0b\x32*.apollo.planning_internal.SampleLayerDebug\x12.\n\x0emin_cost_point\x18\x02 \x03(\x0b\x32\x16.apollo.common.SLPoint\"\xa0\x01\n\rScenarioDebug\x12\x43\n\rscenario_type\x18\x01 \x01(\x0e\x32,.apollo.planning.ScenarioConfig.ScenarioType\x12=\n\nstage_type\x18\x02 \x01(\x0e\x32).apollo.planning.ScenarioConfig.StageType\x12\x0b\n\x03msg\x18\x03 \x01(\t\"=\n\x0cTrajectories\x12-\n\ntrajectory\x18\x01 \x03(\x0b\x32\x19.apollo.common.Trajectory\"\xd5\x07\n\x0eOpenSpaceDebug\x12<\n\x0ctrajectories\x18\x01 \x01(\x0b\x32&.apollo.planning_internal.Trajectories\x12;\n\x15warm_start_trajectory\x18\x02 \x01(\x0b\x32\x1c.apollo.common.VehicleMotion\x12\x39\n\x13smoothed_trajectory\x18\x03 \x01(\x0b\x32\x1c.apollo.common.VehicleMotion\x12\x1e\n\x16warm_start_dual_lambda\x18\x04 \x03(\x01\x12\x1b\n\x13warm_start_dual_miu\x18\x05 \x03(\x01\x12\x1d\n\x15optimized_dual_lambda\x18\x06 \x03(\x01\x12\x1a\n\x12optimized_dual_miu\x18\x07 \x03(\x01\x12\x13\n\x0bxy_boundary\x18\x08 \x03(\x01\x12:\n\tobstacles\x18\t \x03(\x0b\x32\'.apollo.planning_internal.ObstacleDebug\x12\x37\n\x0froi_shift_point\x18\n \x01(\x0b\x32\x1e.apollo.common.TrajectoryPoint\x12\x31\n\tend_point\x18\x0b \x01(\x0b\x32\x1e.apollo.common.TrajectoryPoint\x12H\n\x18partitioned_trajectories\x18\x0c \x01(\x0b\x32&.apollo.planning_internal.Trajectories\x12\x41\n\x11\x63hosen_trajectory\x18\r \x01(\x0b\x32&.apollo.planning_internal.Trajectories\x12\x1e\n\x16is_fallback_trajectory\x18\x0e \x01(\x08\x12\x43\n\x13\x66\x61llback_trajectory\x18\x0f \x01(\x0b\x32&.apollo.planning_internal.Trajectories\x12\x42\n\x1atrajectory_stitching_point\x18\x10 \x01(\x0b\x32\x1e.apollo.common.TrajectoryPoint\x12>\n\x16\x66uture_collision_point\x18\x11 \x01(\x0b\x32\x1e.apollo.common.TrajectoryPoint\x12\x17\n\x0ctime_latency\x18\x12 \x01(\x01:\x01\x30\x12-\n\x0corigin_point\x18\x13 \x01(\x0b\x32\x17.apollo.common.PointENU\x12\x1a\n\x12origin_heading_rad\x18\x14 \x01(\x01\"\xc3\x01\n\rSmootherDebug\x12\x13\n\x0bis_smoothed\x18\x01 \x01(\x08\x12Q\n\x04type\x18\x02 \x01(\x0e\x32\x34.apollo.planning_internal.SmootherDebug.SmootherType:\rSMOOTHER_NONE\x12\x0e\n\x06reason\x18\x03 \x01(\t\":\n\x0cSmootherType\x12\x11\n\rSMOOTHER_NONE\x10\x01\x12\x17\n\x13SMOOTHER_CLOSE_STOP\x10\x02\"\x9d\x01\n\rPullOverDebug\x12)\n\x08position\x18\x01 \x01(\x0b\x32\x17.apollo.common.PointENU\x12\r\n\x05theta\x18\x02 \x01(\x01\x12\x14\n\x0clength_front\x18\x03 \x01(\x01\x12\x13\n\x0blength_back\x18\x04 \x01(\x01\x12\x12\n\nwidth_left\x18\x05 \x01(\x01\x12\x13\n\x0bwidth_right\x18\x06 \x01(\x01\"\xad\n\n\x0cPlanningData\x12?\n\x0c\x61\x64\x63_position\x18\x07 \x01(\x0b\x32).apollo.localization.LocalizationEstimate\x12\'\n\x07\x63hassis\x18\x08 \x01(\x0b\x32\x16.apollo.canbus.Chassis\x12\x30\n\x07routing\x18\t \x01(\x0b\x32\x1f.apollo.routing.RoutingResponse\x12\x32\n\ninit_point\x18\n \x01(\x0b\x32\x1e.apollo.common.TrajectoryPoint\x12!\n\x04path\x18\x06 \x03(\x0b\x32\x13.apollo.common.Path\x12\x37\n\nspeed_plan\x18\r \x03(\x0b\x32#.apollo.planning_internal.SpeedPlan\x12\x38\n\x08st_graph\x18\x0e \x03(\x0b\x32&.apollo.planning_internal.STGraphDebug\x12\x38\n\x08sl_frame\x18\x0f \x03(\x0b\x32&.apollo.planning_internal.SLFrameDebug\x12\x30\n\x11prediction_header\x18\x10 \x01(\x0b\x32\x15.apollo.common.Header\x12@\n\x0csignal_light\x18\x11 \x01(\x0b\x32*.apollo.planning_internal.SignalLightDebug\x12\x39\n\x08obstacle\x18\x12 \x03(\x0b\x32\'.apollo.planning_internal.ObstacleDebug\x12\x44\n\x0ereference_line\x18\x13 \x03(\x0b\x32,.apollo.planning_internal.ReferenceLineDebug\x12\x41\n\rdp_poly_graph\x18\x14 \x01(\x0b\x32*.apollo.planning_internal.DpPolyGraphDebug\x12\x45\n\x10lattice_st_image\x18\x15 \x01(\x0b\x32+.apollo.planning_internal.LatticeStTraining\x12\x31\n\x0crelative_map\x18\x16 \x01(\x0b\x32\x1b.apollo.relative_map.MapMsg\x12S\n\x19\x61uto_tuning_training_data\x18\x17 \x01(\x0b\x32\x30.apollo.planning_internal.AutoTuningTrainingData\x12\x1c\n\x14\x66ront_clear_distance\x18\x18 \x01(\x01\x12&\n\x05\x63hart\x18\x19 \x03(\x0b\x32\x17.apollo.dreamview.Chart\x12\x39\n\x08scenario\x18\x1a \x01(\x0b\x32\'.apollo.planning_internal.ScenarioDebug\x12<\n\nopen_space\x18\x1b \x01(\x0b\x32(.apollo.planning_internal.OpenSpaceDebug\x12\x39\n\x08smoother\x18\x1c \x01(\x0b\x32\'.apollo.planning_internal.SmootherDebug\x12:\n\tpull_over\x18\x1d \x01(\x0b\x32\'.apollo.planning_internal.PullOverDebug\x12@\n\x0chybrid_model\x18\x1e \x01(\x0b\x32*.apollo.planning_internal.HybridModelDebug\"G\n\x0eLatticeStPixel\x12\t\n\x01s\x18\x01 \x01(\x05\x12\t\n\x01t\x18\x02 \x01(\x05\x12\t\n\x01r\x18\x03 \x01(\r\x12\t\n\x01g\x18\x04 \x01(\r\x12\t\n\x01\x62\x18\x05 \x01(\r\"\xc9\x01\n\x11LatticeStTraining\x12\x37\n\x05pixel\x18\x01 \x03(\x0b\x32(.apollo.planning_internal.LatticeStPixel\x12\x11\n\ttimestamp\x18\x02 \x01(\x01\x12\x12\n\nannotation\x18\x03 \x01(\t\x12\x13\n\x0bnum_s_grids\x18\x04 \x01(\r\x12\x13\n\x0bnum_t_grids\x18\x05 \x01(\r\x12\x14\n\x0cs_resolution\x18\x06 \x01(\x01\x12\x14\n\x0ct_resolution\x18\x07 \x01(\x01\"(\n\x0e\x43ostComponents\x12\x16\n\x0e\x63ost_component\x18\x01 \x03(\x01\"\xa2\x01\n\x16\x41utoTuningTrainingData\x12\x43\n\x11teacher_component\x18\x01 \x01(\x0b\x32(.apollo.planning_internal.CostComponents\x12\x43\n\x11student_component\x18\x02 \x01(\x0b\x32(.apollo.planning_internal.CostComponents\"N\n\x19\x43loudReferenceLineRequest\x12\x31\n\x0clane_segment\x18\x01 \x03(\x0b\x32\x1b.apollo.routing.LaneSegment\"T\n CloudReferenceLineRoutingRequest\x12\x30\n\x07routing\x18\x01 \x01(\x0b\x32\x1f.apollo.routing.RoutingResponse\"B\n\x1a\x43loudReferenceLineResponse\x12$\n\x07segment\x18\x01 \x03(\x0b\x32\x13.apollo.common.Path\"\xcb\x01\n\x10HybridModelDebug\x12*\n\x1busing_learning_model_output\x18\x01 \x01(\x08:\x05\x66\x61lse\x12)\n!learning_model_output_usage_ratio\x18\x02 \x01(\x01\x12)\n!learning_model_output_fail_reason\x18\x03 \x01(\t\x12\x35\n\x18\x65valuated_path_reference\x18\x04 \x01(\x0b\x32\x13.apollo.common.Path'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_geometry__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,modules_dot_canbus_dot_proto_dot_chassis__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_pnc__point__pb2.DESCRIPTOR,modules_dot_localization_dot_proto_dot_localization__pb2.DESCRIPTOR,modules_dot_dreamview_dot_proto_dot_chart__pb2.DESCRIPTOR,modules_dot_map_dot_relative__map_dot_proto_dot_navigation__pb2.DESCRIPTOR,modules_dot_routing_dot_proto_dot_routing__pb2.DESCRIPTOR,modules_dot_perception_dot_proto_dot_traffic__light__detection__pb2.DESCRIPTOR,modules_dot_planning_dot_proto_dot_sl__boundary__pb2.DESCRIPTOR,modules_dot_planning_dot_proto_dot_decision__pb2.DESCRIPTOR,modules_dot_planning_dot_proto_dot_planning__config__pb2.DESCRIPTOR,])



_STGRAPHBOUNDARYDEBUG_STBOUNDARYTYPE = _descriptor.EnumDescriptor(
  name='StBoundaryType',
  full_name='apollo.planning_internal.StGraphBoundaryDebug.StBoundaryType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ST_BOUNDARY_TYPE_UNKNOWN', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ST_BOUNDARY_TYPE_STOP', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ST_BOUNDARY_TYPE_FOLLOW', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ST_BOUNDARY_TYPE_YIELD', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ST_BOUNDARY_TYPE_OVERTAKE', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ST_BOUNDARY_TYPE_KEEP_CLEAR', index=5, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ST_BOUNDARY_TYPE_DRIVABLE_REGION', index=6, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=881,
  serialized_end=1113,
)
_sym_db.RegisterEnumDescriptor(_STGRAPHBOUNDARYDEBUG_STBOUNDARYTYPE)

_SMOOTHERDEBUG_SMOOTHERTYPE = _descriptor.EnumDescriptor(
  name='SmootherType',
  full_name='apollo.planning_internal.SmootherDebug.SmootherType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SMOOTHER_NONE', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SMOOTHER_CLOSE_STOP', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4648,
  serialized_end=4706,
)
_sym_db.RegisterEnumDescriptor(_SMOOTHERDEBUG_SMOOTHERTYPE)


_DEBUG = _descriptor.Descriptor(
  name='Debug',
  full_name='apollo.planning_internal.Debug',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='planning_data', full_name='apollo.planning_internal.Debug.planning_data', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=575,
  serialized_end=645,
)


_SPEEDPLAN = _descriptor.Descriptor(
  name='SpeedPlan',
  full_name='apollo.planning_internal.SpeedPlan',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.planning_internal.SpeedPlan.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_point', full_name='apollo.planning_internal.SpeedPlan.speed_point', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=647,
  serialized_end=720,
)


_STGRAPHBOUNDARYDEBUG = _descriptor.Descriptor(
  name='StGraphBoundaryDebug',
  full_name='apollo.planning_internal.StGraphBoundaryDebug',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.planning_internal.StGraphBoundaryDebug.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='point', full_name='apollo.planning_internal.StGraphBoundaryDebug.point', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='apollo.planning_internal.StGraphBoundaryDebug.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STGRAPHBOUNDARYDEBUG_STBOUNDARYTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=723,
  serialized_end=1113,
)


_SLFRAMEDEBUG = _descriptor.Descriptor(
  name='SLFrameDebug',
  full_name='apollo.planning_internal.SLFrameDebug',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.planning_internal.SLFrameDebug.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sampled_s', full_name='apollo.planning_internal.SLFrameDebug.sampled_s', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='static_obstacle_lower_bound', full_name='apollo.planning_internal.SLFrameDebug.static_obstacle_lower_bound', index=2,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dynamic_obstacle_lower_bound', full_name='apollo.planning_internal.SLFrameDebug.dynamic_obstacle_lower_bound', index=3,
      number=4, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='static_obstacle_upper_bound', full_name='apollo.planning_internal.SLFrameDebug.static_obstacle_upper_bound', index=4,
      number=5, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dynamic_obstacle_upper_bound', full_name='apollo.planning_internal.SLFrameDebug.dynamic_obstacle_upper_bound', index=5,
      number=6, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='map_lower_bound', full_name='apollo.planning_internal.SLFrameDebug.map_lower_bound', index=6,
      number=7, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='map_upper_bound', full_name='apollo.planning_internal.SLFrameDebug.map_upper_bound', index=7,
      number=8, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sl_path', full_name='apollo.planning_internal.SLFrameDebug.sl_path', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aggregated_boundary_s', full_name='apollo.planning_internal.SLFrameDebug.aggregated_boundary_s', index=9,
      number=10, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aggregated_boundary_low', full_name='apollo.planning_internal.SLFrameDebug.aggregated_boundary_low', index=10,
      number=11, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aggregated_boundary_high', full_name='apollo.planning_internal.SLFrameDebug.aggregated_boundary_high', index=11,
      number=12, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1116,
  serialized_end=1502,
)


_STGRAPHDEBUG_STGRAPHSPEEDCONSTRAINT = _descriptor.Descriptor(
  name='STGraphSpeedConstraint',
  full_name='apollo.planning_internal.STGraphDebug.STGraphSpeedConstraint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='t', full_name='apollo.planning_internal.STGraphDebug.STGraphSpeedConstraint.t', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lower_bound', full_name='apollo.planning_internal.STGraphDebug.STGraphSpeedConstraint.lower_bound', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upper_bound', full_name='apollo.planning_internal.STGraphDebug.STGraphSpeedConstraint.upper_bound', index=2,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1967,
  serialized_end=2044,
)

_STGRAPHDEBUG_STGRAPHKERNELCUISEREF = _descriptor.Descriptor(
  name='STGraphKernelCuiseRef',
  full_name='apollo.planning_internal.STGraphDebug.STGraphKernelCuiseRef',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='t', full_name='apollo.planning_internal.STGraphDebug.STGraphKernelCuiseRef.t', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cruise_line_s', full_name='apollo.planning_internal.STGraphDebug.STGraphKernelCuiseRef.cruise_line_s', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2046,
  serialized_end=2103,
)

_STGRAPHDEBUG_STGRAPHKERNELFOLLOWREF = _descriptor.Descriptor(
  name='STGraphKernelFollowRef',
  full_name='apollo.planning_internal.STGraphDebug.STGraphKernelFollowRef',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='t', full_name='apollo.planning_internal.STGraphDebug.STGraphKernelFollowRef.t', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='follow_line_s', full_name='apollo.planning_internal.STGraphDebug.STGraphKernelFollowRef.follow_line_s', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2105,
  serialized_end=2163,
)

_STGRAPHDEBUG = _descriptor.Descriptor(
  name='STGraphDebug',
  full_name='apollo.planning_internal.STGraphDebug',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.planning_internal.STGraphDebug.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='boundary', full_name='apollo.planning_internal.STGraphDebug.boundary', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_limit', full_name='apollo.planning_internal.STGraphDebug.speed_limit', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_profile', full_name='apollo.planning_internal.STGraphDebug.speed_profile', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_constraint', full_name='apollo.planning_internal.STGraphDebug.speed_constraint', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kernel_cruise_ref', full_name='apollo.planning_internal.STGraphDebug.kernel_cruise_ref', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kernel_follow_ref', full_name='apollo.planning_internal.STGraphDebug.kernel_follow_ref', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STGRAPHDEBUG_STGRAPHSPEEDCONSTRAINT, _STGRAPHDEBUG_STGRAPHKERNELCUISEREF, _STGRAPHDEBUG_STGRAPHKERNELFOLLOWREF, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1505,
  serialized_end=2163,
)


_SIGNALLIGHTDEBUG_SIGNALDEBUG = _descriptor.Descriptor(
  name='SignalDebug',
  full_name='apollo.planning_internal.SignalLightDebug.SignalDebug',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='light_id', full_name='apollo.planning_internal.SignalLightDebug.SignalDebug.light_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='color', full_name='apollo.planning_internal.SignalLightDebug.SignalDebug.color', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='light_stop_s', full_name='apollo.planning_internal.SignalLightDebug.SignalDebug.light_stop_s', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_stop_deceleration', full_name='apollo.planning_internal.SignalLightDebug.SignalDebug.adc_stop_deceleration', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_stop_wall_created', full_name='apollo.planning_internal.SignalLightDebug.SignalDebug.is_stop_wall_created', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2299,
  serialized_end=2467,
)

_SIGNALLIGHTDEBUG = _descriptor.Descriptor(
  name='SignalLightDebug',
  full_name='apollo.planning_internal.SignalLightDebug',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='adc_speed', full_name='apollo.planning_internal.SignalLightDebug.adc_speed', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_front_s', full_name='apollo.planning_internal.SignalLightDebug.adc_front_s', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal', full_name='apollo.planning_internal.SignalLightDebug.signal', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SIGNALLIGHTDEBUG_SIGNALDEBUG, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2166,
  serialized_end=2467,
)


_DECISIONTAG = _descriptor.Descriptor(
  name='DecisionTag',
  full_name='apollo.planning_internal.DecisionTag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='decider_tag', full_name='apollo.planning_internal.DecisionTag.decider_tag', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decision', full_name='apollo.planning_internal.DecisionTag.decision', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2469,
  serialized_end=2558,
)


_OBSTACLEDEBUG = _descriptor.Descriptor(
  name='ObstacleDebug',
  full_name='apollo.planning_internal.ObstacleDebug',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.planning_internal.ObstacleDebug.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sl_boundary', full_name='apollo.planning_internal.ObstacleDebug.sl_boundary', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decision_tag', full_name='apollo.planning_internal.ObstacleDebug.decision_tag', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vertices_x_coords', full_name='apollo.planning_internal.ObstacleDebug.vertices_x_coords', index=3,
      number=4, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vertices_y_coords', full_name='apollo.planning_internal.ObstacleDebug.vertices_y_coords', index=4,
      number=5, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2561,
  serialized_end=2753,
)


_REFERENCELINEDEBUG = _descriptor.Descriptor(
  name='ReferenceLineDebug',
  full_name='apollo.planning_internal.ReferenceLineDebug',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.planning_internal.ReferenceLineDebug.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length', full_name='apollo.planning_internal.ReferenceLineDebug.length', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cost', full_name='apollo.planning_internal.ReferenceLineDebug.cost', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_change_lane_path', full_name='apollo.planning_internal.ReferenceLineDebug.is_change_lane_path', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_drivable', full_name='apollo.planning_internal.ReferenceLineDebug.is_drivable', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_protected', full_name='apollo.planning_internal.ReferenceLineDebug.is_protected', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_offroad', full_name='apollo.planning_internal.ReferenceLineDebug.is_offroad', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minimum_boundary', full_name='apollo.planning_internal.ReferenceLineDebug.minimum_boundary', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='average_kappa', full_name='apollo.planning_internal.ReferenceLineDebug.average_kappa', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='average_dkappa', full_name='apollo.planning_internal.ReferenceLineDebug.average_dkappa', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kappa_rms', full_name='apollo.planning_internal.ReferenceLineDebug.kappa_rms', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dkappa_rms', full_name='apollo.planning_internal.ReferenceLineDebug.dkappa_rms', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kappa_max_abs', full_name='apollo.planning_internal.ReferenceLineDebug.kappa_max_abs', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dkappa_max_abs', full_name='apollo.planning_internal.ReferenceLineDebug.dkappa_max_abs', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='average_offset', full_name='apollo.planning_internal.ReferenceLineDebug.average_offset', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2756,
  serialized_end=3101,
)


_SAMPLELAYERDEBUG = _descriptor.Descriptor(
  name='SampleLayerDebug',
  full_name='apollo.planning_internal.SampleLayerDebug',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sl_point', full_name='apollo.planning_internal.SampleLayerDebug.sl_point', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3103,
  serialized_end=3163,
)


_DPPOLYGRAPHDEBUG = _descriptor.Descriptor(
  name='DpPolyGraphDebug',
  full_name='apollo.planning_internal.DpPolyGraphDebug',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sample_layer', full_name='apollo.planning_internal.DpPolyGraphDebug.sample_layer', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_cost_point', full_name='apollo.planning_internal.DpPolyGraphDebug.min_cost_point', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3166,
  serialized_end=3298,
)


_SCENARIODEBUG = _descriptor.Descriptor(
  name='ScenarioDebug',
  full_name='apollo.planning_internal.ScenarioDebug',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scenario_type', full_name='apollo.planning_internal.ScenarioDebug.scenario_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stage_type', full_name='apollo.planning_internal.ScenarioDebug.stage_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msg', full_name='apollo.planning_internal.ScenarioDebug.msg', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3301,
  serialized_end=3461,
)


_TRAJECTORIES = _descriptor.Descriptor(
  name='Trajectories',
  full_name='apollo.planning_internal.Trajectories',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trajectory', full_name='apollo.planning_internal.Trajectories.trajectory', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3463,
  serialized_end=3524,
)


_OPENSPACEDEBUG = _descriptor.Descriptor(
  name='OpenSpaceDebug',
  full_name='apollo.planning_internal.OpenSpaceDebug',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trajectories', full_name='apollo.planning_internal.OpenSpaceDebug.trajectories', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='warm_start_trajectory', full_name='apollo.planning_internal.OpenSpaceDebug.warm_start_trajectory', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='smoothed_trajectory', full_name='apollo.planning_internal.OpenSpaceDebug.smoothed_trajectory', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='warm_start_dual_lambda', full_name='apollo.planning_internal.OpenSpaceDebug.warm_start_dual_lambda', index=3,
      number=4, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='warm_start_dual_miu', full_name='apollo.planning_internal.OpenSpaceDebug.warm_start_dual_miu', index=4,
      number=5, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optimized_dual_lambda', full_name='apollo.planning_internal.OpenSpaceDebug.optimized_dual_lambda', index=5,
      number=6, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optimized_dual_miu', full_name='apollo.planning_internal.OpenSpaceDebug.optimized_dual_miu', index=6,
      number=7, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='xy_boundary', full_name='apollo.planning_internal.OpenSpaceDebug.xy_boundary', index=7,
      number=8, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacles', full_name='apollo.planning_internal.OpenSpaceDebug.obstacles', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roi_shift_point', full_name='apollo.planning_internal.OpenSpaceDebug.roi_shift_point', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_point', full_name='apollo.planning_internal.OpenSpaceDebug.end_point', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partitioned_trajectories', full_name='apollo.planning_internal.OpenSpaceDebug.partitioned_trajectories', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chosen_trajectory', full_name='apollo.planning_internal.OpenSpaceDebug.chosen_trajectory', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_fallback_trajectory', full_name='apollo.planning_internal.OpenSpaceDebug.is_fallback_trajectory', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fallback_trajectory', full_name='apollo.planning_internal.OpenSpaceDebug.fallback_trajectory', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trajectory_stitching_point', full_name='apollo.planning_internal.OpenSpaceDebug.trajectory_stitching_point', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='future_collision_point', full_name='apollo.planning_internal.OpenSpaceDebug.future_collision_point', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_latency', full_name='apollo.planning_internal.OpenSpaceDebug.time_latency', index=17,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origin_point', full_name='apollo.planning_internal.OpenSpaceDebug.origin_point', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origin_heading_rad', full_name='apollo.planning_internal.OpenSpaceDebug.origin_heading_rad', index=19,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3527,
  serialized_end=4508,
)


_SMOOTHERDEBUG = _descriptor.Descriptor(
  name='SmootherDebug',
  full_name='apollo.planning_internal.SmootherDebug',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_smoothed', full_name='apollo.planning_internal.SmootherDebug.is_smoothed', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='apollo.planning_internal.SmootherDebug.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='apollo.planning_internal.SmootherDebug.reason', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SMOOTHERDEBUG_SMOOTHERTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4511,
  serialized_end=4706,
)


_PULLOVERDEBUG = _descriptor.Descriptor(
  name='PullOverDebug',
  full_name='apollo.planning_internal.PullOverDebug',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='position', full_name='apollo.planning_internal.PullOverDebug.position', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='theta', full_name='apollo.planning_internal.PullOverDebug.theta', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length_front', full_name='apollo.planning_internal.PullOverDebug.length_front', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length_back', full_name='apollo.planning_internal.PullOverDebug.length_back', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width_left', full_name='apollo.planning_internal.PullOverDebug.width_left', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width_right', full_name='apollo.planning_internal.PullOverDebug.width_right', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4709,
  serialized_end=4866,
)


_PLANNINGDATA = _descriptor.Descriptor(
  name='PlanningData',
  full_name='apollo.planning_internal.PlanningData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='adc_position', full_name='apollo.planning_internal.PlanningData.adc_position', index=0,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chassis', full_name='apollo.planning_internal.PlanningData.chassis', index=1,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='routing', full_name='apollo.planning_internal.PlanningData.routing', index=2,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='init_point', full_name='apollo.planning_internal.PlanningData.init_point', index=3,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='apollo.planning_internal.PlanningData.path', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_plan', full_name='apollo.planning_internal.PlanningData.speed_plan', index=5,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='st_graph', full_name='apollo.planning_internal.PlanningData.st_graph', index=6,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sl_frame', full_name='apollo.planning_internal.PlanningData.sl_frame', index=7,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prediction_header', full_name='apollo.planning_internal.PlanningData.prediction_header', index=8,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal_light', full_name='apollo.planning_internal.PlanningData.signal_light', index=9,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle', full_name='apollo.planning_internal.PlanningData.obstacle', index=10,
      number=18, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reference_line', full_name='apollo.planning_internal.PlanningData.reference_line', index=11,
      number=19, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dp_poly_graph', full_name='apollo.planning_internal.PlanningData.dp_poly_graph', index=12,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lattice_st_image', full_name='apollo.planning_internal.PlanningData.lattice_st_image', index=13,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relative_map', full_name='apollo.planning_internal.PlanningData.relative_map', index=14,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_tuning_training_data', full_name='apollo.planning_internal.PlanningData.auto_tuning_training_data', index=15,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='front_clear_distance', full_name='apollo.planning_internal.PlanningData.front_clear_distance', index=16,
      number=24, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chart', full_name='apollo.planning_internal.PlanningData.chart', index=17,
      number=25, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scenario', full_name='apollo.planning_internal.PlanningData.scenario', index=18,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='open_space', full_name='apollo.planning_internal.PlanningData.open_space', index=19,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='smoother', full_name='apollo.planning_internal.PlanningData.smoother', index=20,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pull_over', full_name='apollo.planning_internal.PlanningData.pull_over', index=21,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hybrid_model', full_name='apollo.planning_internal.PlanningData.hybrid_model', index=22,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4869,
  serialized_end=6194,
)


_LATTICESTPIXEL = _descriptor.Descriptor(
  name='LatticeStPixel',
  full_name='apollo.planning_internal.LatticeStPixel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='s', full_name='apollo.planning_internal.LatticeStPixel.s', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='t', full_name='apollo.planning_internal.LatticeStPixel.t', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='r', full_name='apollo.planning_internal.LatticeStPixel.r', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='g', full_name='apollo.planning_internal.LatticeStPixel.g', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='b', full_name='apollo.planning_internal.LatticeStPixel.b', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6196,
  serialized_end=6267,
)


_LATTICESTTRAINING = _descriptor.Descriptor(
  name='LatticeStTraining',
  full_name='apollo.planning_internal.LatticeStTraining',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pixel', full_name='apollo.planning_internal.LatticeStTraining.pixel', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='apollo.planning_internal.LatticeStTraining.timestamp', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='annotation', full_name='apollo.planning_internal.LatticeStTraining.annotation', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_s_grids', full_name='apollo.planning_internal.LatticeStTraining.num_s_grids', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_t_grids', full_name='apollo.planning_internal.LatticeStTraining.num_t_grids', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='s_resolution', full_name='apollo.planning_internal.LatticeStTraining.s_resolution', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='t_resolution', full_name='apollo.planning_internal.LatticeStTraining.t_resolution', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6270,
  serialized_end=6471,
)


_COSTCOMPONENTS = _descriptor.Descriptor(
  name='CostComponents',
  full_name='apollo.planning_internal.CostComponents',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cost_component', full_name='apollo.planning_internal.CostComponents.cost_component', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6473,
  serialized_end=6513,
)


_AUTOTUNINGTRAININGDATA = _descriptor.Descriptor(
  name='AutoTuningTrainingData',
  full_name='apollo.planning_internal.AutoTuningTrainingData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='teacher_component', full_name='apollo.planning_internal.AutoTuningTrainingData.teacher_component', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='student_component', full_name='apollo.planning_internal.AutoTuningTrainingData.student_component', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6516,
  serialized_end=6678,
)


_CLOUDREFERENCELINEREQUEST = _descriptor.Descriptor(
  name='CloudReferenceLineRequest',
  full_name='apollo.planning_internal.CloudReferenceLineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane_segment', full_name='apollo.planning_internal.CloudReferenceLineRequest.lane_segment', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6680,
  serialized_end=6758,
)


_CLOUDREFERENCELINEROUTINGREQUEST = _descriptor.Descriptor(
  name='CloudReferenceLineRoutingRequest',
  full_name='apollo.planning_internal.CloudReferenceLineRoutingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='routing', full_name='apollo.planning_internal.CloudReferenceLineRoutingRequest.routing', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6760,
  serialized_end=6844,
)


_CLOUDREFERENCELINERESPONSE = _descriptor.Descriptor(
  name='CloudReferenceLineResponse',
  full_name='apollo.planning_internal.CloudReferenceLineResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='segment', full_name='apollo.planning_internal.CloudReferenceLineResponse.segment', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6846,
  serialized_end=6912,
)


_HYBRIDMODELDEBUG = _descriptor.Descriptor(
  name='HybridModelDebug',
  full_name='apollo.planning_internal.HybridModelDebug',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='using_learning_model_output', full_name='apollo.planning_internal.HybridModelDebug.using_learning_model_output', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='learning_model_output_usage_ratio', full_name='apollo.planning_internal.HybridModelDebug.learning_model_output_usage_ratio', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='learning_model_output_fail_reason', full_name='apollo.planning_internal.HybridModelDebug.learning_model_output_fail_reason', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='evaluated_path_reference', full_name='apollo.planning_internal.HybridModelDebug.evaluated_path_reference', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6915,
  serialized_end=7118,
)

_DEBUG.fields_by_name['planning_data'].message_type = _PLANNINGDATA
_SPEEDPLAN.fields_by_name['speed_point'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._SPEEDPOINT
_STGRAPHBOUNDARYDEBUG.fields_by_name['point'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._SPEEDPOINT
_STGRAPHBOUNDARYDEBUG.fields_by_name['type'].enum_type = _STGRAPHBOUNDARYDEBUG_STBOUNDARYTYPE
_STGRAPHBOUNDARYDEBUG_STBOUNDARYTYPE.containing_type = _STGRAPHBOUNDARYDEBUG
_SLFRAMEDEBUG.fields_by_name['sl_path'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._SLPOINT
_STGRAPHDEBUG_STGRAPHSPEEDCONSTRAINT.containing_type = _STGRAPHDEBUG
_STGRAPHDEBUG_STGRAPHKERNELCUISEREF.containing_type = _STGRAPHDEBUG
_STGRAPHDEBUG_STGRAPHKERNELFOLLOWREF.containing_type = _STGRAPHDEBUG
_STGRAPHDEBUG.fields_by_name['boundary'].message_type = _STGRAPHBOUNDARYDEBUG
_STGRAPHDEBUG.fields_by_name['speed_limit'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._SPEEDPOINT
_STGRAPHDEBUG.fields_by_name['speed_profile'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._SPEEDPOINT
_STGRAPHDEBUG.fields_by_name['speed_constraint'].message_type = _STGRAPHDEBUG_STGRAPHSPEEDCONSTRAINT
_STGRAPHDEBUG.fields_by_name['kernel_cruise_ref'].message_type = _STGRAPHDEBUG_STGRAPHKERNELCUISEREF
_STGRAPHDEBUG.fields_by_name['kernel_follow_ref'].message_type = _STGRAPHDEBUG_STGRAPHKERNELFOLLOWREF
_SIGNALLIGHTDEBUG_SIGNALDEBUG.fields_by_name['color'].enum_type = modules_dot_perception_dot_proto_dot_traffic__light__detection__pb2._TRAFFICLIGHT_COLOR
_SIGNALLIGHTDEBUG_SIGNALDEBUG.containing_type = _SIGNALLIGHTDEBUG
_SIGNALLIGHTDEBUG.fields_by_name['signal'].message_type = _SIGNALLIGHTDEBUG_SIGNALDEBUG
_DECISIONTAG.fields_by_name['decision'].message_type = modules_dot_planning_dot_proto_dot_decision__pb2._OBJECTDECISIONTYPE
_OBSTACLEDEBUG.fields_by_name['sl_boundary'].message_type = modules_dot_planning_dot_proto_dot_sl__boundary__pb2._SLBOUNDARY
_OBSTACLEDEBUG.fields_by_name['decision_tag'].message_type = _DECISIONTAG
_SAMPLELAYERDEBUG.fields_by_name['sl_point'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._SLPOINT
_DPPOLYGRAPHDEBUG.fields_by_name['sample_layer'].message_type = _SAMPLELAYERDEBUG
_DPPOLYGRAPHDEBUG.fields_by_name['min_cost_point'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._SLPOINT
_SCENARIODEBUG.fields_by_name['scenario_type'].enum_type = modules_dot_planning_dot_proto_dot_planning__config__pb2._SCENARIOCONFIG_SCENARIOTYPE
_SCENARIODEBUG.fields_by_name['stage_type'].enum_type = modules_dot_planning_dot_proto_dot_planning__config__pb2._SCENARIOCONFIG_STAGETYPE
_TRAJECTORIES.fields_by_name['trajectory'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._TRAJECTORY
_OPENSPACEDEBUG.fields_by_name['trajectories'].message_type = _TRAJECTORIES
_OPENSPACEDEBUG.fields_by_name['warm_start_trajectory'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._VEHICLEMOTION
_OPENSPACEDEBUG.fields_by_name['smoothed_trajectory'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._VEHICLEMOTION
_OPENSPACEDEBUG.fields_by_name['obstacles'].message_type = _OBSTACLEDEBUG
_OPENSPACEDEBUG.fields_by_name['roi_shift_point'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._TRAJECTORYPOINT
_OPENSPACEDEBUG.fields_by_name['end_point'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._TRAJECTORYPOINT
_OPENSPACEDEBUG.fields_by_name['partitioned_trajectories'].message_type = _TRAJECTORIES
_OPENSPACEDEBUG.fields_by_name['chosen_trajectory'].message_type = _TRAJECTORIES
_OPENSPACEDEBUG.fields_by_name['fallback_trajectory'].message_type = _TRAJECTORIES
_OPENSPACEDEBUG.fields_by_name['trajectory_stitching_point'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._TRAJECTORYPOINT
_OPENSPACEDEBUG.fields_by_name['future_collision_point'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._TRAJECTORYPOINT
_OPENSPACEDEBUG.fields_by_name['origin_point'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINTENU
_SMOOTHERDEBUG.fields_by_name['type'].enum_type = _SMOOTHERDEBUG_SMOOTHERTYPE
_SMOOTHERDEBUG_SMOOTHERTYPE.containing_type = _SMOOTHERDEBUG
_PULLOVERDEBUG.fields_by_name['position'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINTENU
_PLANNINGDATA.fields_by_name['adc_position'].message_type = modules_dot_localization_dot_proto_dot_localization__pb2._LOCALIZATIONESTIMATE
_PLANNINGDATA.fields_by_name['chassis'].message_type = modules_dot_canbus_dot_proto_dot_chassis__pb2._CHASSIS
_PLANNINGDATA.fields_by_name['routing'].message_type = modules_dot_routing_dot_proto_dot_routing__pb2._ROUTINGRESPONSE
_PLANNINGDATA.fields_by_name['init_point'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._TRAJECTORYPOINT
_PLANNINGDATA.fields_by_name['path'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._PATH
_PLANNINGDATA.fields_by_name['speed_plan'].message_type = _SPEEDPLAN
_PLANNINGDATA.fields_by_name['st_graph'].message_type = _STGRAPHDEBUG
_PLANNINGDATA.fields_by_name['sl_frame'].message_type = _SLFRAMEDEBUG
_PLANNINGDATA.fields_by_name['prediction_header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_PLANNINGDATA.fields_by_name['signal_light'].message_type = _SIGNALLIGHTDEBUG
_PLANNINGDATA.fields_by_name['obstacle'].message_type = _OBSTACLEDEBUG
_PLANNINGDATA.fields_by_name['reference_line'].message_type = _REFERENCELINEDEBUG
_PLANNINGDATA.fields_by_name['dp_poly_graph'].message_type = _DPPOLYGRAPHDEBUG
_PLANNINGDATA.fields_by_name['lattice_st_image'].message_type = _LATTICESTTRAINING
_PLANNINGDATA.fields_by_name['relative_map'].message_type = modules_dot_map_dot_relative__map_dot_proto_dot_navigation__pb2._MAPMSG
_PLANNINGDATA.fields_by_name['auto_tuning_training_data'].message_type = _AUTOTUNINGTRAININGDATA
_PLANNINGDATA.fields_by_name['chart'].message_type = modules_dot_dreamview_dot_proto_dot_chart__pb2._CHART
_PLANNINGDATA.fields_by_name['scenario'].message_type = _SCENARIODEBUG
_PLANNINGDATA.fields_by_name['open_space'].message_type = _OPENSPACEDEBUG
_PLANNINGDATA.fields_by_name['smoother'].message_type = _SMOOTHERDEBUG
_PLANNINGDATA.fields_by_name['pull_over'].message_type = _PULLOVERDEBUG
_PLANNINGDATA.fields_by_name['hybrid_model'].message_type = _HYBRIDMODELDEBUG
_LATTICESTTRAINING.fields_by_name['pixel'].message_type = _LATTICESTPIXEL
_AUTOTUNINGTRAININGDATA.fields_by_name['teacher_component'].message_type = _COSTCOMPONENTS
_AUTOTUNINGTRAININGDATA.fields_by_name['student_component'].message_type = _COSTCOMPONENTS
_CLOUDREFERENCELINEREQUEST.fields_by_name['lane_segment'].message_type = modules_dot_routing_dot_proto_dot_routing__pb2._LANESEGMENT
_CLOUDREFERENCELINEROUTINGREQUEST.fields_by_name['routing'].message_type = modules_dot_routing_dot_proto_dot_routing__pb2._ROUTINGRESPONSE
_CLOUDREFERENCELINERESPONSE.fields_by_name['segment'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._PATH
_HYBRIDMODELDEBUG.fields_by_name['evaluated_path_reference'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._PATH
DESCRIPTOR.message_types_by_name['Debug'] = _DEBUG
DESCRIPTOR.message_types_by_name['SpeedPlan'] = _SPEEDPLAN
DESCRIPTOR.message_types_by_name['StGraphBoundaryDebug'] = _STGRAPHBOUNDARYDEBUG
DESCRIPTOR.message_types_by_name['SLFrameDebug'] = _SLFRAMEDEBUG
DESCRIPTOR.message_types_by_name['STGraphDebug'] = _STGRAPHDEBUG
DESCRIPTOR.message_types_by_name['SignalLightDebug'] = _SIGNALLIGHTDEBUG
DESCRIPTOR.message_types_by_name['DecisionTag'] = _DECISIONTAG
DESCRIPTOR.message_types_by_name['ObstacleDebug'] = _OBSTACLEDEBUG
DESCRIPTOR.message_types_by_name['ReferenceLineDebug'] = _REFERENCELINEDEBUG
DESCRIPTOR.message_types_by_name['SampleLayerDebug'] = _SAMPLELAYERDEBUG
DESCRIPTOR.message_types_by_name['DpPolyGraphDebug'] = _DPPOLYGRAPHDEBUG
DESCRIPTOR.message_types_by_name['ScenarioDebug'] = _SCENARIODEBUG
DESCRIPTOR.message_types_by_name['Trajectories'] = _TRAJECTORIES
DESCRIPTOR.message_types_by_name['OpenSpaceDebug'] = _OPENSPACEDEBUG
DESCRIPTOR.message_types_by_name['SmootherDebug'] = _SMOOTHERDEBUG
DESCRIPTOR.message_types_by_name['PullOverDebug'] = _PULLOVERDEBUG
DESCRIPTOR.message_types_by_name['PlanningData'] = _PLANNINGDATA
DESCRIPTOR.message_types_by_name['LatticeStPixel'] = _LATTICESTPIXEL
DESCRIPTOR.message_types_by_name['LatticeStTraining'] = _LATTICESTTRAINING
DESCRIPTOR.message_types_by_name['CostComponents'] = _COSTCOMPONENTS
DESCRIPTOR.message_types_by_name['AutoTuningTrainingData'] = _AUTOTUNINGTRAININGDATA
DESCRIPTOR.message_types_by_name['CloudReferenceLineRequest'] = _CLOUDREFERENCELINEREQUEST
DESCRIPTOR.message_types_by_name['CloudReferenceLineRoutingRequest'] = _CLOUDREFERENCELINEROUTINGREQUEST
DESCRIPTOR.message_types_by_name['CloudReferenceLineResponse'] = _CLOUDREFERENCELINERESPONSE
DESCRIPTOR.message_types_by_name['HybridModelDebug'] = _HYBRIDMODELDEBUG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Debug = _reflection.GeneratedProtocolMessageType('Debug', (_message.Message,), {
  'DESCRIPTOR' : _DEBUG,
  '__module__' : 'modules.planning.proto.planning_internal_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning_internal.Debug)
  })
_sym_db.RegisterMessage(Debug)

SpeedPlan = _reflection.GeneratedProtocolMessageType('SpeedPlan', (_message.Message,), {
  'DESCRIPTOR' : _SPEEDPLAN,
  '__module__' : 'modules.planning.proto.planning_internal_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning_internal.SpeedPlan)
  })
_sym_db.RegisterMessage(SpeedPlan)

StGraphBoundaryDebug = _reflection.GeneratedProtocolMessageType('StGraphBoundaryDebug', (_message.Message,), {
  'DESCRIPTOR' : _STGRAPHBOUNDARYDEBUG,
  '__module__' : 'modules.planning.proto.planning_internal_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning_internal.StGraphBoundaryDebug)
  })
_sym_db.RegisterMessage(StGraphBoundaryDebug)

SLFrameDebug = _reflection.GeneratedProtocolMessageType('SLFrameDebug', (_message.Message,), {
  'DESCRIPTOR' : _SLFRAMEDEBUG,
  '__module__' : 'modules.planning.proto.planning_internal_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning_internal.SLFrameDebug)
  })
_sym_db.RegisterMessage(SLFrameDebug)

STGraphDebug = _reflection.GeneratedProtocolMessageType('STGraphDebug', (_message.Message,), {

  'STGraphSpeedConstraint' : _reflection.GeneratedProtocolMessageType('STGraphSpeedConstraint', (_message.Message,), {
    'DESCRIPTOR' : _STGRAPHDEBUG_STGRAPHSPEEDCONSTRAINT,
    '__module__' : 'modules.planning.proto.planning_internal_pb2'
    # @@protoc_insertion_point(class_scope:apollo.planning_internal.STGraphDebug.STGraphSpeedConstraint)
    })
  ,

  'STGraphKernelCuiseRef' : _reflection.GeneratedProtocolMessageType('STGraphKernelCuiseRef', (_message.Message,), {
    'DESCRIPTOR' : _STGRAPHDEBUG_STGRAPHKERNELCUISEREF,
    '__module__' : 'modules.planning.proto.planning_internal_pb2'
    # @@protoc_insertion_point(class_scope:apollo.planning_internal.STGraphDebug.STGraphKernelCuiseRef)
    })
  ,

  'STGraphKernelFollowRef' : _reflection.GeneratedProtocolMessageType('STGraphKernelFollowRef', (_message.Message,), {
    'DESCRIPTOR' : _STGRAPHDEBUG_STGRAPHKERNELFOLLOWREF,
    '__module__' : 'modules.planning.proto.planning_internal_pb2'
    # @@protoc_insertion_point(class_scope:apollo.planning_internal.STGraphDebug.STGraphKernelFollowRef)
    })
  ,
  'DESCRIPTOR' : _STGRAPHDEBUG,
  '__module__' : 'modules.planning.proto.planning_internal_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning_internal.STGraphDebug)
  })
_sym_db.RegisterMessage(STGraphDebug)
_sym_db.RegisterMessage(STGraphDebug.STGraphSpeedConstraint)
_sym_db.RegisterMessage(STGraphDebug.STGraphKernelCuiseRef)
_sym_db.RegisterMessage(STGraphDebug.STGraphKernelFollowRef)

SignalLightDebug = _reflection.GeneratedProtocolMessageType('SignalLightDebug', (_message.Message,), {

  'SignalDebug' : _reflection.GeneratedProtocolMessageType('SignalDebug', (_message.Message,), {
    'DESCRIPTOR' : _SIGNALLIGHTDEBUG_SIGNALDEBUG,
    '__module__' : 'modules.planning.proto.planning_internal_pb2'
    # @@protoc_insertion_point(class_scope:apollo.planning_internal.SignalLightDebug.SignalDebug)
    })
  ,
  'DESCRIPTOR' : _SIGNALLIGHTDEBUG,
  '__module__' : 'modules.planning.proto.planning_internal_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning_internal.SignalLightDebug)
  })
_sym_db.RegisterMessage(SignalLightDebug)
_sym_db.RegisterMessage(SignalLightDebug.SignalDebug)

DecisionTag = _reflection.GeneratedProtocolMessageType('DecisionTag', (_message.Message,), {
  'DESCRIPTOR' : _DECISIONTAG,
  '__module__' : 'modules.planning.proto.planning_internal_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning_internal.DecisionTag)
  })
_sym_db.RegisterMessage(DecisionTag)

ObstacleDebug = _reflection.GeneratedProtocolMessageType('ObstacleDebug', (_message.Message,), {
  'DESCRIPTOR' : _OBSTACLEDEBUG,
  '__module__' : 'modules.planning.proto.planning_internal_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning_internal.ObstacleDebug)
  })
_sym_db.RegisterMessage(ObstacleDebug)

ReferenceLineDebug = _reflection.GeneratedProtocolMessageType('ReferenceLineDebug', (_message.Message,), {
  'DESCRIPTOR' : _REFERENCELINEDEBUG,
  '__module__' : 'modules.planning.proto.planning_internal_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning_internal.ReferenceLineDebug)
  })
_sym_db.RegisterMessage(ReferenceLineDebug)

SampleLayerDebug = _reflection.GeneratedProtocolMessageType('SampleLayerDebug', (_message.Message,), {
  'DESCRIPTOR' : _SAMPLELAYERDEBUG,
  '__module__' : 'modules.planning.proto.planning_internal_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning_internal.SampleLayerDebug)
  })
_sym_db.RegisterMessage(SampleLayerDebug)

DpPolyGraphDebug = _reflection.GeneratedProtocolMessageType('DpPolyGraphDebug', (_message.Message,), {
  'DESCRIPTOR' : _DPPOLYGRAPHDEBUG,
  '__module__' : 'modules.planning.proto.planning_internal_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning_internal.DpPolyGraphDebug)
  })
_sym_db.RegisterMessage(DpPolyGraphDebug)

ScenarioDebug = _reflection.GeneratedProtocolMessageType('ScenarioDebug', (_message.Message,), {
  'DESCRIPTOR' : _SCENARIODEBUG,
  '__module__' : 'modules.planning.proto.planning_internal_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning_internal.ScenarioDebug)
  })
_sym_db.RegisterMessage(ScenarioDebug)

Trajectories = _reflection.GeneratedProtocolMessageType('Trajectories', (_message.Message,), {
  'DESCRIPTOR' : _TRAJECTORIES,
  '__module__' : 'modules.planning.proto.planning_internal_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning_internal.Trajectories)
  })
_sym_db.RegisterMessage(Trajectories)

OpenSpaceDebug = _reflection.GeneratedProtocolMessageType('OpenSpaceDebug', (_message.Message,), {
  'DESCRIPTOR' : _OPENSPACEDEBUG,
  '__module__' : 'modules.planning.proto.planning_internal_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning_internal.OpenSpaceDebug)
  })
_sym_db.RegisterMessage(OpenSpaceDebug)

SmootherDebug = _reflection.GeneratedProtocolMessageType('SmootherDebug', (_message.Message,), {
  'DESCRIPTOR' : _SMOOTHERDEBUG,
  '__module__' : 'modules.planning.proto.planning_internal_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning_internal.SmootherDebug)
  })
_sym_db.RegisterMessage(SmootherDebug)

PullOverDebug = _reflection.GeneratedProtocolMessageType('PullOverDebug', (_message.Message,), {
  'DESCRIPTOR' : _PULLOVERDEBUG,
  '__module__' : 'modules.planning.proto.planning_internal_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning_internal.PullOverDebug)
  })
_sym_db.RegisterMessage(PullOverDebug)

PlanningData = _reflection.GeneratedProtocolMessageType('PlanningData', (_message.Message,), {
  'DESCRIPTOR' : _PLANNINGDATA,
  '__module__' : 'modules.planning.proto.planning_internal_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning_internal.PlanningData)
  })
_sym_db.RegisterMessage(PlanningData)

LatticeStPixel = _reflection.GeneratedProtocolMessageType('LatticeStPixel', (_message.Message,), {
  'DESCRIPTOR' : _LATTICESTPIXEL,
  '__module__' : 'modules.planning.proto.planning_internal_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning_internal.LatticeStPixel)
  })
_sym_db.RegisterMessage(LatticeStPixel)

LatticeStTraining = _reflection.GeneratedProtocolMessageType('LatticeStTraining', (_message.Message,), {
  'DESCRIPTOR' : _LATTICESTTRAINING,
  '__module__' : 'modules.planning.proto.planning_internal_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning_internal.LatticeStTraining)
  })
_sym_db.RegisterMessage(LatticeStTraining)

CostComponents = _reflection.GeneratedProtocolMessageType('CostComponents', (_message.Message,), {
  'DESCRIPTOR' : _COSTCOMPONENTS,
  '__module__' : 'modules.planning.proto.planning_internal_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning_internal.CostComponents)
  })
_sym_db.RegisterMessage(CostComponents)

AutoTuningTrainingData = _reflection.GeneratedProtocolMessageType('AutoTuningTrainingData', (_message.Message,), {
  'DESCRIPTOR' : _AUTOTUNINGTRAININGDATA,
  '__module__' : 'modules.planning.proto.planning_internal_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning_internal.AutoTuningTrainingData)
  })
_sym_db.RegisterMessage(AutoTuningTrainingData)

CloudReferenceLineRequest = _reflection.GeneratedProtocolMessageType('CloudReferenceLineRequest', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDREFERENCELINEREQUEST,
  '__module__' : 'modules.planning.proto.planning_internal_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning_internal.CloudReferenceLineRequest)
  })
_sym_db.RegisterMessage(CloudReferenceLineRequest)

CloudReferenceLineRoutingRequest = _reflection.GeneratedProtocolMessageType('CloudReferenceLineRoutingRequest', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDREFERENCELINEROUTINGREQUEST,
  '__module__' : 'modules.planning.proto.planning_internal_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning_internal.CloudReferenceLineRoutingRequest)
  })
_sym_db.RegisterMessage(CloudReferenceLineRoutingRequest)

CloudReferenceLineResponse = _reflection.GeneratedProtocolMessageType('CloudReferenceLineResponse', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDREFERENCELINERESPONSE,
  '__module__' : 'modules.planning.proto.planning_internal_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning_internal.CloudReferenceLineResponse)
  })
_sym_db.RegisterMessage(CloudReferenceLineResponse)

HybridModelDebug = _reflection.GeneratedProtocolMessageType('HybridModelDebug', (_message.Message,), {
  'DESCRIPTOR' : _HYBRIDMODELDEBUG,
  '__module__' : 'modules.planning.proto.planning_internal_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning_internal.HybridModelDebug)
  })
_sym_db.RegisterMessage(HybridModelDebug)


_REFERENCELINEDEBUG.fields_by_name['average_kappa']._options = None
_REFERENCELINEDEBUG.fields_by_name['average_dkappa']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/control/proto/pid_conf.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/control/proto/pid_conf.proto',
  package='apollo.control',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$modules/control/proto/pid_conf.proto\x12\x0e\x61pollo.control\"\x9e\x01\n\x07PidConf\x12\x19\n\x11integrator_enable\x18\x01 \x01(\x08\x12#\n\x1bintegrator_saturation_level\x18\x02 \x01(\x01\x12\n\n\x02kp\x18\x03 \x01(\x01\x12\n\n\x02ki\x18\x04 \x01(\x01\x12\n\n\x02kd\x18\x05 \x01(\x01\x12\x0e\n\x03kaw\x18\x06 \x01(\x01:\x01\x30\x12\x1f\n\x17output_saturation_level\x18\x07 \x01(\x01'
)




_PIDCONF = _descriptor.Descriptor(
  name='PidConf',
  full_name='apollo.control.PidConf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='integrator_enable', full_name='apollo.control.PidConf.integrator_enable', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='integrator_saturation_level', full_name='apollo.control.PidConf.integrator_saturation_level', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kp', full_name='apollo.control.PidConf.kp', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ki', full_name='apollo.control.PidConf.ki', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kd', full_name='apollo.control.PidConf.kd', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kaw', full_name='apollo.control.PidConf.kaw', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_saturation_level', full_name='apollo.control.PidConf.output_saturation_level', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=57,
  serialized_end=215,
)

DESCRIPTOR.message_types_by_name['PidConf'] = _PIDCONF
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PidConf = _reflection.GeneratedProtocolMessageType('PidConf', (_message.Message,), {
  'DESCRIPTOR' : _PIDCONF,
  '__module__' : 'modules.control.proto.pid_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.control.PidConf)
  })
_sym_db.RegisterMessage(PidConf)


# @@protoc_insertion_point(module_scope)
